@@ -27,7 +27,7 @@
 #include <KMime/Message>
 #include <KMime/Util>
 
-#include <KCodecs/KEmailAddress>
+#include <KEmailAddress>
 
 #include <KLocalizedString>
 
@@ -218,7 +218,7 @@ void Key::publishPKS()
     const char *gpgName = GpgME::engineInfo(GpgME::OpenPGP).fileName();
     auto gpgProcess = new QProcess;
     gpgProcess->setProperty("keyServer", keyServer);
-    connect(gpgProcess, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, &Key::onPKSPublishingFinished);
+    connect(gpgProcess, &QProcess::finished, this, &Key::onPKSPublishingFinished);
     mJob = gpgProcess;
     gpgProcess->start(QString::fromLatin1(gpgName),
                       {QStringLiteral("--keyserver"), keyServer, QStringLiteral("--send-keys"), QString::fromLatin1(m_key.primaryFingerprint())});
